SciDB-Py documentation — SciDB-Py 14.7.0 documentation

# SciDB-Py documentation

SciDB-Py is a Python interface to the SciDB, the massively scalable array-oriented database. SciDB features include ACID transactions, parallel processing, distributed storage, efficient sparse array storage, and native parallel linear algebra operations.

The SciDB-Py package provides an intuitive NumPy-like interface to SciDB, so that users can leverage powerful distributed, data-parallel scientific computing from the comfort of their Python interpreter:

    from scidbpy import connect
    sdb = connect()              # connect to the database
    x = sdb.random((1000, 1000)) # 2D array of random numbers
    y = (x ** 2 + 3).sum()       # NumPy syntax, computed in the database

# Contents

- Whats New
  - 14.7 (Released August 1, 2014)
- Installing SciDB-Py
  - Software prerequisites
  - Python Prerequisites
  - SciDB-Py Package Installation
- Basic Use
  - Introduction to SciDB arrays
  - Loading the scidbpy package and connecting to SciDB
  - Creating arrays
  - Accessing array data
  - Operations on SciDB array objects
  - Comparing and Filtering Arrays
  - The SciDB Query Interface
  - Downloading SciDBArrays
- Demos and Other Topics
- API Documentation
  - Class Reference
  - AFL Operator Reference

# Indices and tables

- Index
- Module Index
- Search Page